@@ -26,4 +26,7 @@ def fixSeed(seed, p = True):
     # use_deterministic_algorithms : deterministic보다 더 넓은 범위 커버, non-deterministic한 알고리즘이 존재하는 경우 Error 발생
     # pytorch 1.8.0부터 사용
     # torch.use_deterministic_algorithms(True)
-    if p: print("torch : {} \tcuda : {} \tnumpy : {}".format(torch.initial_seed(), torch.cuda.initial_seed(), np.random.get_state()[1][0]))
\ No newline at end of file
+    if p: print("torch : {} \tcuda : {} \tnumpy : {}".format(torch.initial_seed(), torch.cuda.initial_seed(), np.random.get_state()[1][0]))
+
+def to_np(v):
+    return v.detach().cpu().numpy()
